#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.52.1
visibility:           public
id:                   hledger-1.52.1-FbOCC9uvDcb9xJs6ryvjkJ
key:                  hledger-1.52.1-FbOCC9uvDcb9xJs6ryvjkJ
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  33aeb2377d59bceb8bd558c95b902706
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anchor Hledger.Cli.Anon
    Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Aregister
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Run
    Hledger.Cli.Commands.Setup Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.52.1-FbOCC9uvDcb9xJs6ryvjkJ
depends:
    Decimal-0.5.2-EOg69NZd2UJ5udglLDXh6B
    Diff-1.0-38Pk9ggjoQQ3bTSUZHJGAf
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V
    ansi-terminal-1.1-DloTwXdDsLxGyTkENbfyqg base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    directory-1.3.8.5 extra-1.7.16-JqlpUalRpf3DrrxiVQYUyX
    filepath-1.4.300.1 githash-0.1.7.0-LCZwCOSUHSa2LjoI5e07WB
    hashable-1.4.7.0-A1kp0rRlB2mBNtk1x2NHGT haskeline-0.8.2.1
    hledger-lib-1.52.1-J1KGASvBZbe8OCGuaHaZyj
    http-client-0.7.19-4lCfHST9XIV9y3pAbrfMCv
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    lucid-2.11.20260427-4cRu67Gl39GFurd8CjX4OD
    math-functions-0.3.4.4-ByR5e67yQWHHWjOe4RAPKR
    megaparsec-9.7.1-lfMyUtNLhmEXQ4ic9tvxz
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    modern-uri-0.3.6.1-IXoUzdjNr0p4hYXzNr0vdC mtl-2.3.1
    process-1.6.19.0 regex-tdfa-1.3.2.6-7s6a3kMa1YssqXiRAnHSe
    req-3.13.4-8nvmVwKeYwZId76DQEaZx7
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    shakespeare-2.2.0-A7a3ny4Zor96v3NfYEsb8D
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.4-IL2dKu3GamJ8dAyKzmzJIp
    temporary-1.3-1ezn4dc6wi13jwuWHEP4w4 text-2.0.2
    text-ansi-0.3.0.1-GzimmUxnfNb6lAgU6zl2ha time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    unordered-containers-0.2.21-1uyZH24PObnIj7baK8tBEp
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    utility-ht-0.0.17.2-7JeB7DsoB0DB67XpMDvpYk
    wizards-1.0.3-EMndOhiYuHdGTEqrX5mo0v

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

